@@ -3,7 +3,7 @@ package Email::MIME::Attachment::Stripper;
 use strict;
 use warnings;
 
-our $VERSION = '1.31';
+our $VERSION = '1.311';
 
 use Email::MIME;
 use Email::MIME::Modifier;
@@ -57,12 +57,16 @@ alter both the body and the header of the message.
 This returns a list of all the attachments we found in the message,
 as a hash of { filename, content_type, payload }.
 
+=head1 PERL EMAIL PROJECT
+
+This module is maintained by the Perl Email Project
+
+  L<http://emailproject.perl.org/wiki/Email::MIME::Attachment::Stripper>
+
 =head1 AUTHOR
 
 Casey West <casey@geeknest.com>
 
-http://pep.kwiki.org
-
 =head1 CREDITS AND LICENSE
 
 This module is incredibly closely derived from Tony Bowden's
